@@ -6,11 +6,11 @@ from setuptools_cpp_cuda import CudaExtension, BuildExtension, fix_dll
 
 cuda_ext_path = Path('src/my_cuda_package/cudaest')
 cuda_ext = CudaExtension(
-    name='my_cuda_package.cudaext',
+    name='my_cuda_package.cuda_ext',
     include_dirs=[cuda_ext_path / 'include'],
     sources=[
-        cuda_ext_path / 'cudaext.cu',
-        cuda_ext_path / 'cudaext_wrapper.cpp',
+        cuda_ext_path / 'cuda_ext.cu',
+        cuda_ext_path / 'cuda_ext_wrapper.cpp',
     ],
     libraries=fix_dll(['cudart']),  # Use fix_dll() only for Windows compatibility (check documentation for more info).
     extra_compile_args={
