@@ -4,13 +4,13 @@ from setuptools import setup
 
 from setuptools_cpp_cuda import CudaExtension, BuildExtension, fix_dll
 
-cuda_ext_path = Path('src/my_cuda_package/cudaest')
+cuda_ext_path = Path('src/my_cuda_package/cuda_ext')
 cuda_ext = CudaExtension(
-    name='my_cuda_package.cudaext',
+    name='my_cuda_package.cuda_ext',
     include_dirs=[cuda_ext_path / 'include'],
     sources=[
-        cuda_ext_path / 'cudaext.cu',
-        cuda_ext_path / 'cudaext_wrapper.cpp',
+        cuda_ext_path / 'cuda_ext.cu',
+        cuda_ext_path / 'cuda_ext_wrapper.cpp',
     ],
     libraries=fix_dll(['cudart']),  # Use fix_dll() only for Windows compatibility (check documentation for more info).
     extra_compile_args={
@@ -26,5 +26,4 @@ setup(
     extras_require={'cython': ['cython'], },
     ext_modules=[cuda_ext],
     cmdclass={'build_ext': BuildExtension},
-    # zip_safe=False,
 )
